@@ -175,7 +175,7 @@ def get_full_integrations(platform: str, service_code: str) -> list:
     return results
 
 
-def check_entities_equal(db_entity: any, new_entity: any) -> bool:
+def check_entities_equal(db_entity: any, new_entity: any, exclude_fields: Union[list, tuple, None] = None) -> bool:
     """
     :param db_entity: any
     :param new_entity: any
@@ -183,7 +183,8 @@ def check_entities_equal(db_entity: any, new_entity: any) -> bool:
     """
     db_entity = db_entity.__dict__
     new_entity = new_entity.__dict__
-    exclude_fields = ('_state', 'date_time', 'sc_date_time', 'funnel_stage_duration', 'id')
+    if not exclude_fields:
+        exclude_fields = ('_state', 'date_time', 'sc_date_time', 'funnel_stage_duration', 'id')
     return all((field, new_entity[field]) in db_entity.items() for field in db_entity if field not in exclude_fields)
 
 
